```{highlight} shell

```

# Installation

## Stable release

To install PyTimings, run this command in your terminal:

```{code-block} console

$ pip install pytimings

```

This is the preferred method to install PyTimings, as it will always install the most recent stable release.

If you don't have [pip][pip] installed, this [Python installation guide][python installation guide] can guide
you through the process.

[pip]: https://pip.pypa.io/en/stable/

[python installation guide]: http://docs.python-guide.org/en/latest/starting/installation/

## From sources

The sources for PyTimings can be downloaded from the [Github repo][github repo].

You can either clone the public repository:

```{code-block} console

$ git clone git://github.com/renefritze/pytimings

```

Or download the [tarball][tarball]:

```{code-block} console

$ curl -OJL https://github.com/renefritze/pytimings/tarball/main

```

Once you have a copy of the source, you can install it with:

```{code-block} console

$ pip install .

```

[github repo]: https://github.com/renefritze/pytimings

[tarball]: https://github.com/renefritze/pytimings/tarball/main
